@@ -1,6 +1,14 @@
 from typing import Awaitable, Callable
 import asyncio
 import logging
+import sys
+
+if sys.platform == "linux":
+    try:
+        import uvloop
+        uvloop.install()
+    except:
+        pass
 
 
 class async_runner:
