@@ -45,6 +45,8 @@ class dbmysql:
 
         self.col_functions = []
 
+        self.last_insert_id = None
+
         self.connect()
 
         self.__periodic_check()
@@ -168,7 +170,8 @@ class dbmysql:
             password=self.password,
             database=self.database,
             charset='utf8',
-            autocommit=self.autocommit
+            autocommit=self.autocommit,
+            cursorclass=pymysql.cursors.SSDictCursor
         )
         self.flush_tables_cache()
 
@@ -179,23 +182,19 @@ class dbmysql:
         try:
             self.conn.commit()
         except Exception as e:
-            if e.args[0] == 2013:
-                raise(e)
-            return None
+            raise(e)
 
     def __execute_err_reconnect(self, fn, *args):
         try:
             ret = fn(*args)
         except Exception as e:
-            if e.args[0] == 2013:
-                try:
-                    self.conn.ping()
-                    logging.info("Reconnecting to mysql ...")
-                except Exception as e:
-                    logging.error(e.with_traceback(None))
-                    return None
+            try:
+                logging.info("Reconnecting to mysql ...")
+                self.conn.ping()
+                logging.info("ReExecute sql ...")
                 ret = fn(*args)
-            else:
+            except Exception as e:
+                logging.error(f"error : {e.args}")
                 return None
         return ret
 
@@ -230,24 +229,20 @@ class dbmysql:
             params = (123)
         """
         try:
-            cursor: pymysql.cursors.Cursor = self.conn.cursor(
-                cursor=pymysql.cursors.SSDictCursor)
-            ret = cursor.execute(sql, params)
-            if ret <= 0:
-                ret = None
-            else:
-                ret = cursor.fetchall()
-                if len(ret) <= 0:
+            with self.conn.cursor() as cursor:
+                ret = cursor.execute(sql, params)
+                if ret <= 0:
                     ret = None
-            cursor.close()
-            self.__need_commit = True
-            return ret
+                else:
+                    ret = cursor.fetchall()
+                    if len(ret) <= 0:
+                        ret = None
+                self.__need_commit = True
+                return ret
         except Exception as e:
-            logging.error(f"db get error {e.with_traceback(None)}")
-            logging.error(f"get sql error:{sql},params = {str(params)}")
-            if e.args[0] == 2013:
-                raise(e)
-            return None
+            logging.error(f"db get error {e.args}")
+            logging.error(f"get sql error:{sql}, params = {str(params)}")
+            raise(e)
 
     def select(self, table: str, cols: list, where: dict = {}, order_by: str = "",  limit: int = None, offset: int = None, order_direction: str = "asc", inject: str = ""):
         """
@@ -319,16 +314,14 @@ class dbmysql:
             params = [123, 'hahaha']
         """
         try:
-            cursor: pymysql.cursors.Cursor = self.conn.cursor()
-            cursor.execute(sql, params)
-            cursor.close()
-            self.__need_commit = True
+            with self.conn.cursor() as cursor:
+                cursor.execute(sql, params)
+                self.last_insert_id = cursor.lastrowid
+                self.__need_commit = True
         except Exception as e:
-            logging.error(e.with_traceback(None))
+            logging.error(f"db get error {e.args}")
             logging.error(f"post sql error:{sql}, params = {str(params)}")
-            if e.args[0] == 2013:
-                raise(e)
-            return None
+            raise(e)
         return True
 
     def exec_proc(self, name: str, args: Union[List, Tuple] = (), ret_count: Union[List, Tuple] = ()) -> tuple:
@@ -366,21 +359,18 @@ class dbmysql:
             结果为folderid = (60,)
         """
         try:
-            cursor: pymysql.cursors.Cursor = self.conn.cursor()
-            cursor.callproc(name, args)
-            params = ",".join(f"@_{name}_{i}" for i in ret_count)
-            s_result_sql = f"select {params}"
-            cursor.execute(s_result_sql)
-            result = cursor.fetchone()
-            cursor.close()
-            self.__need_commit = True
-            return result
+            with self.conn.cursor() as cursor:
+                cursor.callproc(name, args)
+                params = ",".join(f"@_{name}_{i}" for i in ret_count)
+                s_result_sql = f"select {params}"
+                cursor.execute(s_result_sql)
+                result = cursor.fetchone()
+                self.__need_commit = True
+                return result
         except Exception as e:
-            logging.error(e.with_traceback(None))
-            logging.error(f"excute procedure error:{name},args = {str(args)}")
-            if e.args[0] == 2013:
-                raise(e)
-            return None
+            logging.error(f"db get error {e.args}")
+            logging.error(f"excute procedure error:{name}, args = {str(args)}")
+            raise(e)
 
     def update(self, table: str, values: dict, where: dict = {}, values_func: dict = None, inject: str = ""):
         """
@@ -405,14 +395,14 @@ class dbmysql:
                             logging.error(
                                 f"{f} not in {self.allow_values_func}")
                             return
-                        set_string += f"`{k}` = {f}(%s) "
+                        set_string += f"`{k}` = {f}(%s), "
                     else:
-                        set_string += f"`{k}` = %s "
+                        set_string += f"`{k}` = %s, "
                 else:
-                    set_string += f"`{k}` = %s "
+                    set_string += f"`{k}` = %s, "
                 args.append(v)
 
-        sql += set_string
+        sql += set_string[:-2]
 
         # 构建where筛选语句
         where_str, where_args = self.__make_where(col_names, where)
@@ -638,21 +628,16 @@ class DbMysqlHelper:
                  database: str,
                  autocommit: bool = True,
                  loop: asyncio.AbstractEventLoop = None) -> None:
-        self._db = dbmysql(host, port, user, password, "", autocommit, loop)
-        self.database = database
-        if not self.has_db(database):
-            self._db.post(f"create database `{database}`")
-            self._db.conn.select_db(database)
-            self._db.database = database
-            if not autocommit:
-                self._db.commit()
-        else:
-            self._db.conn.select_db(database)
-            self._db.database = database
+        db = dbmysql(host, port, user, password, "", True, loop)
+        if not self.__has_db(db, database):
+            db.post(f"create database `{database}`")
+
+        self._db = dbmysql(host, port, user, password,
+                           database, autocommit, loop)
         self.tables_sql = {}
 
-    def has_db(self, db_name: str) -> bool:
-        dbs = self._db.get("show databases")
+    def __has_db(self, dbmysql: dbmysql, db_name: str) -> bool:
+        dbs = dbmysql.get("show databases")
         for db in dbs:
             if db['Database'] == db_name:
                 return True
@@ -670,5 +655,3 @@ class DbMysqlHelper:
     @property
     def db(self) -> dbmysql:
         return self._db
-
-
